@@ -108,7 +108,7 @@ class BasicTextView(text_view.TextView):
 	def new(self,*data):
 		if (self.get_modified() == True):
 			dlg =  dialog.Dialog(_("Start new without saving ?"),
-			("Cancel", dialog.Dialog.BUTTON_ID_1,_("Start-New!"), dialog.Dialog.BUTTON_ID_2))                           						
+			(_("Cancel"), dialog.Dialog.BUTTON_ID_1,_("Start-New!"), dialog.Dialog.BUTTON_ID_2))
 			label = widget.Label(_("Start new without saving ?"))
 			dlg.add_widget(label)
 			label.show()
@@ -132,7 +132,7 @@ class BasicTextView(text_view.TextView):
 	def open(self):
 		open_file = file_chooser.FileChooserDialog(_("Select the file to open"),
 			file_chooser.FileChooserDialog.OPEN,
-			macros.supported_text_formats,macros.home_dir)
+			macros.supported_text_formats,macros.user_home_path)
 		response = open_file.run()
 		if response == file_chooser.FileChooserDialog.ACCEPT:
 			to_open = read_text_from_file(open_file.get_filename())
@@ -223,7 +223,7 @@ class BasicTextView(text_view.TextView):
 	def export_text_cleaner_list(self,*data):
 		open_file = file_chooser.FileChooserDialog(_("Filename please"),
 		file_chooser.FileChooserDialog.SAVE,
-		macros.supported_text_formats,macros.home_dir)
+		macros.supported_text_formats,macros.user_home_path)
 		open_file.set_current_name(".txt")
 		response = open_file.run()
 		if response == file_chooser.FileChooserDialog.ACCEPT:
@@ -233,17 +233,17 @@ class BasicTextView(text_view.TextView):
 	def import_text_cleaner_list(self,*data):
 		open_file = file_chooser.FileChooserDialog(_("Select the file to import"),
 		file_chooser.FileChooserDialog.OPEN,
-		"*",macros.home_dir)
+		"*",macros.user_home_path)
 		response = open_file.run()
 		if response == file_chooser.FileChooserDialog.ACCEPT:
 			self.set_text_cleaner_list_from_file(open_file.get_filename())
-			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 		open_file.destroy()
 
 	def open_text_cleaner(self,*data):
 		window_text_cleaner = window.Window(_("Text Cleaner"))
 		scroll_box = containers.ScrollBox()
-		treeview = tree_view.TreeView([("Match",str,True),("Replace",str,True)],None)
+		treeview = tree_view.TreeView([(_("Match"),str,True),(_("Replace"),str,True)],None)
 		scroll_box.add(treeview)
 		treeview.set_list(self.text_cleaner_list)
 
@@ -259,14 +259,14 @@ class BasicTextView(text_view.TextView):
 			if (response == dialog.Dialog.BUTTON_ID_1):
 				treeview.append((entry_match.get_text(),entry_replace.get_text()))
 				self.text_cleaner_list = treeview.get_list()
-				self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+				self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 			dlg.destroy()
 
 		def remove_clicked(*data):
 			index = treeview.get_selected_row_index()
 			treeview.remove(index)
 			self.text_cleaner_list = treeview.get_list()
-			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 
 		def export_list(*data):
 			self.export_text_cleaner_list()
@@ -274,21 +274,21 @@ class BasicTextView(text_view.TextView):
 		def import_list(*data):
 			self.import_text_cleaner_list()
 			treeview.set_list(self.text_cleaner_list)
-			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 
 		def restore(*data):
-			self.set_text_cleaner_list_from_file(macros.default_text_cleaner_list_file)
+			self.set_text_cleaner_list_from_file(macros.default_text_cleaner_list_file_path)
 			treeview.set_list(self.text_cleaner_list)
-			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 
 		def clear(*data):
 			self.text_cleaner_list = []
 			treeview.set_list(self.text_cleaner_list)
-			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 
 		def list_updated(*data):
 			self.text_cleaner_list = treeview.get_list()
-			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file);
+			self.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path);
 
 		def close(*data):
 			window_text_cleaner.close()
@@ -434,10 +434,7 @@ class BasicTextView(text_view.TextView):
 			line_number = item.split("~")[1].split()[0]
 			text = open(filename).read()
 			self.set_text(text)
-			
-			#self.move_cursor_to_line(int(line_number))
-			print(int(line_number),filename)
-			
+
 			self.save_file_name = filename
 			self.import_bookmarks_using_filename()
 			
@@ -486,7 +483,7 @@ class BasicTextView(text_view.TextView):
 	def import_bookmarks_from_file(self,*data):
 		open_file = file_chooser.FileChooserDialog(_("Select the bookmark file to import"),
 			file_chooser.FileChooserDialog.OPEN,
-			macros.supported_text_formats,macros.home_dir)
+			macros.supported_text_formats,macros.user_home_path)
 		response = open_file.run()
 		if response == file_chooser.FileChooserDialog.ACCEPT:
 			with open(open_file.get_filename()) as file:
@@ -606,10 +603,10 @@ class BasicTextView(text_view.TextView):
 				else:
 					break
 			
-		label_word = widget.Label(_("<b> word  : </b>"))
+		label_word = widget.Label(_("<b> Word: </b>"))
 		label_word.set_use_markup(True)
 		label_word.set_mnemonic_widget(entry_word)
-		label_replace_word = widget.Label(_("<b> Replace word : </b>"))
+		label_replace_word = widget.Label(_("<b> Replace word: </b>"))
 		label_replace_word.set_use_markup(True)
 		label_replace_word.set_mnemonic_widget(entry_replace_word)
 		
@@ -623,7 +620,7 @@ class BasicTextView(text_view.TextView):
 		button_previous.connect_function(find_previous)
 		button_replace = widget.Button(_("Replace"))
 		button_replace.connect_function(replace)	
-		button_replace_all = widget.Button(_("Replace-All"))
+		button_replace_all = widget.Button(_("Replace All"))
 		button_replace_all.connect_function(replace_all)
 		
 		
@@ -663,7 +660,7 @@ class BasicTextView(text_view.TextView):
 					break
 			if(self.is_cursor_at_end()):
 				entry.set_text("")
-				statusbar_context.set_text("Spell Check finished")
+				statusbar_context.set_text(_("Spell Check finished"))
 			
 
 		def ignore_all(*data):
@@ -680,7 +677,6 @@ class BasicTextView(text_view.TextView):
 			replace_word = entry.get_text()
 			change_all_dict[self.word] = replace_word
 			self.replace_last_word(replace_word)
-			print(change_all_dict)
 			find_next_mispeleed_word()
 		
 		def delete(*data):
@@ -754,7 +750,7 @@ class BasicTextView(text_view.TextView):
 		else:
 			dlg.destroy()
 	
-	def audio_converter(self,data=None):
+	def audio_converter(self,data=None,voice=None):
 		if (self.has_selection()):
 			text = self.get_selected_text()
 		else:
@@ -782,15 +778,25 @@ class BasicTextView(text_view.TextView):
 		combobox = widget.ComboBox()
 		for item in text_to_audio_converter.list_voices():
 			combobox.append_text(item)
+		if voice is not None:
+			combobox.set_active(voice)
 		label_voice = widget.Label(_("Voice : "))
 		label_voice.set_mnemonic_widget(combobox)
+
+		combobox_format = widget.ComboBox()
+		combobox_format.append_text(_("MP3 (liblame required)"))
+		combobox_format.append_text(_("WAV"))
+		combobox_format.set_active(0)
+		label_format = widget.Label(_("Format : "))
+		label_format.set_mnemonic_widget(combobox_format)
 		
 		grid.add_widgets([
 			(label_speed,1,1),(spinbutton_speed,1,1),containers.Grid.NEW_ROW,
 			(label_volume,1,1),(spinbutton_volume,1,1),containers.Grid.NEW_ROW,
 			(label_pitch,1,1),(spinbutton_pitch,1,1),containers.Grid.NEW_ROW,
 			(label_split_time,1,1),(spinbutton_split,1,1),containers.Grid.NEW_ROW,
-			(label_voice,1,1),(combobox,1,1)])
+			(label_voice,1,1),(combobox,1,1),containers.Grid.NEW_ROW,
+			(label_format,1,1),(combobox_format,1,1)])
 		dialog_ac.add_widget(grid)
 		grid.show_all()
 		
@@ -800,11 +806,15 @@ class BasicTextView(text_view.TextView):
 			volume = spinbutton_volume.get_value()
 			split = spinbutton_split.get_value()
 			voice = combobox.get_active_text()
-			save_file = file_chooser.FileChooserDialog(_("Select the file to open"),file_chooser.FileChooserDialog.SAVE,["wav"],macros.home_dir)
+			output_format = combobox_format.get_active()
+			save_file = file_chooser.FileChooserDialog(_("Save"),file_chooser.FileChooserDialog.SAVE,["wav","mp3"],macros.user_home_path)
 			response = save_file.run()
 			if response == file_chooser.FileChooserDialog.ACCEPT:
 				converter = text_to_audio_converter(text,volume,voice,split,pitch,speed)
-				converter.record_to_wave(save_file.get_filename())
+				if (output_format == 0 ):
+					converter.record_to_mp3(save_file.get_filename())
+				else:
+					converter.record_to_wave(save_file.get_filename())
 			save_file.destroy()
 		dialog_ac.destroy()
 		
@@ -826,7 +836,7 @@ class BasicTextView(text_view.TextView):
 		
 	def print_to_pdf(self,*data):
 		save_file = file_chooser.FileChooserDialog(_("Enter the file name"),
-			file_chooser.FileChooserDialog.SAVE,macros.supported_pdf_formats,macros.home_dir)
+			file_chooser.FileChooserDialog.SAVE,macros.supported_pdf_formats,macros.user_home_path)
 		response = save_file.run()
 		if response == file_chooser.FileChooserDialog.ACCEPT:
 			if (self.has_selection()):
@@ -836,3 +846,4 @@ class BasicTextView(text_view.TextView):
 			print_dialog.print_with_action(text,print_dialog.print_with_action.EXPORT,
 				save_file.get_filename())
 			save_file.destroy()
+
