@@ -55,10 +55,10 @@ class ImageViewer(containers.Paned):
 		self.add(self.scrolled)
 				
 		#Drawing List Tree View
-		self.treeview = tree_view.TreeView([("Selected",bool,False),
-		("X",float,True),("Y",float,True),
-		("Width",float,True),("Height",float,True),
-		("Letter",str,True)],self.edited_callback)
+		self.treeview = tree_view.TreeView([(_("Selected"),bool,False),
+		(_("X"),float,True),(_("Y"),float,True),
+		(_("Width"),float,True),(_("Height"),float,True),
+		(_("Letter"),str,True)],self.edited_callback)
 		
 		self.treeview.connect_cursor_change_function(self.treeview_cursor_changed)
 		self.treeview.connect_rows_reordered_function(self.treeview_rows_reordered)
@@ -78,7 +78,7 @@ class ImageViewer(containers.Paned):
 		button1.connect_function(self.__delete_selection)
 
 		button2 = widget.Button(_("Clear"))
-		button2.connect_function(self.__clear_selection)
+		button2.connect_function(self.clear_selection)
 
 		grid = containers.Grid()
 		grid.add_widgets([(scrolled_treeview,2,1,containers.Grid.HEXPAND,containers.Grid.VEXPAND),
@@ -460,7 +460,7 @@ class ImageViewer(containers.Paned):
 		self.drawingarea.redraw()
 		self.emit('list_updated')
 
-	def __clear_selection(self,widget):
+	def clear_selection(self,widget):
 		self.rs = []
 		self.treeview.clear()
 		# reset selection index
