@@ -58,7 +58,7 @@ class linux_intelligent_ocr_solution():
 			pass
 
 		try:
-			os.mkdir(macros.home_dir+"/lios")
+			os.mkdir(macros.config_dir)
 		except:
 			pass
 
@@ -74,8 +74,8 @@ class linux_intelligent_ocr_solution():
 		scroll_box_iconview.add(self.iconview)
 		box_iconview = containers.Box(containers.Box.VERTICAL)
 		toolbar_iconview = containers.Toolbar(containers.Toolbar.HORIZONTAL,
-			[('Open',self.open_files),(_("Take-Screenshot"),self.take_rectangle_screenshot),
-			(_("Scan-Using-Webcam"),self.scan_using_cam),(_("_Recognize"),self.ocr_selected_images),
+			[(_('Open'),self.open_files),(_("Take-Screenshot"),self.take_rectangle_screenshot),
+			(_("Scan-Using-Webcam"),self.scan_using_cam),(_("Recognize"),self.ocr_selected_images),
 			(_("Clear"),self.iconview_remove_all_images),])
 		#Context menu
 		self.context_menu_iconview = menu.ContextMenu([
@@ -119,16 +119,17 @@ class linux_intelligent_ocr_solution():
 		self.imageview.load_image(macros.logo_file,[],imageview.ImageViewer.ZOOM_FIT)
 		#Context menu
 		self.context_menu_imageview = menu.ContextMenu(
-			[(_("Rotate-Right"),self.rotate_current_images_to_right),
+			[(_("Recognize-Current-Image"),self.ocr_current_image),
+			(_("Recognize-Selected-Areas"),self.ocr_selected_areas),
+			(_("Recognize-Current-Image-With-Rotation"),self.ocr_current_image_with_rotation),menu.SEPARATOR,
+			(_("Rotate-Right"),self.rotate_current_images_to_right),
 			(_("Rotate-Twice"),self.rotate_current_images_to_twice),
 			(_("Rotate-Left"),self.rotate_current_images_to_left),menu.SEPARATOR,
 			(_("Zoom-In"),self.imageview.zoom_in),(_("Zoom-Fit"),self.imageview.zoom_fit),
-			(_("Zoom-Out"),self.imageview.zoom_out),menu.SEPARATOR,
+			(_("Zoom-Out"),self.imageview.zoom_out), menu.SEPARATOR,
 			(_("Train-Selected-Areas"),self.train_selected_areas),
 			(_("Save-Selected-Areas"),self.save_selected_areas),
-			(_("Recognize-Selected-Areas"),self.ocr_selected_areas),
-			(_("Recognize-Current-Image"),self.ocr_current_image),
-			(_("Recognize-Current-Image-With-Rotation"),self.ocr_current_image_with_rotation)]);
+			]);
 		self.imageview.connect_context_menu_button_callback(self.imageview_popup_context_menu)
 
 		
@@ -139,7 +140,7 @@ class linux_intelligent_ocr_solution():
 		self.textview.set_accepts_tab(False)
 		box_editor = containers.Box(containers.Box.HORIZONTAL)
 		toolbar_editor = containers.Toolbar(containers.Toolbar.VERTICAL,
-			[(_("New"),self.new),('Open',self.open_files),
+			[(_("New"),self.new),(_('Open'),self.open_files),
 			(_("Save"),self.textview.save),containers.Toolbar.SEPARATOR,
 			(_("Spell-Check"),self.textview.open_spell_check),containers.Toolbar.SEPARATOR,
 			(_("Undo"),self.textview.undo),(_("Redo"),self.textview.redo),
@@ -147,7 +148,8 @@ class linux_intelligent_ocr_solution():
 			(_("Find"),self.textview.open_find_dialog),
 			(_("Find-Replace"),self.textview.open_find_and_replace_dialog),
 			containers.Toolbar.SEPARATOR,
-			(_("Start/Stop-Reader"),self.start_or_stop_reader),
+			(_("Start-Reader"),self.start_reader),
+			(_("Stop-Reader"),self.stop_reader),
 			containers.Toolbar.SEPARATOR,
 			(_("Go-To-Line"),self.textview.go_to_line),
 			(_("Go-To-Page"),self.go_to_page),
@@ -159,9 +161,9 @@ class linux_intelligent_ocr_solution():
 		box_editor.add(scroll_box_editor)
 
 		#Load TextCleaner List
-		if(not self.textview.set_text_cleaner_list_from_file(macros.local_text_cleaner_list_file)):
-			self.textview.set_text_cleaner_list_from_file(macros.default_text_cleaner_list_file)
-			self.textview.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file)
+		if(not self.textview.set_text_cleaner_list_from_file(macros.local_text_cleaner_list_file_path)):
+			self.textview.set_text_cleaner_list_from_file(macros.default_text_cleaner_list_file_path)
+			self.textview.save_text_cleaner_list_to_file(macros.local_text_cleaner_list_file_path)
 
 
 
@@ -247,13 +249,14 @@ class linux_intelligent_ocr_solution():
 				(_("Export"),self.textview.export_text_cleaner_list,"None"),
 				(_("Apply-From-Cursor"),self.textview.apply_text_cleaner_from_cursor,"None"),
 				(_("Apply-Entire"),self.textview.apply_text_cleaner_entire_text,"None")],
-			(_("Audio-Converter"),self.textview.audio_converter,"None"),
+			(_("Audio-Converter"),self.audio_converter,"None"),
 			(_("Dictionary"),self.artha,"<Control><Alt>W"),
 			(_("Bookmark"),self.textview.create_bookmark,"<Control>B"),
 			(_("Bookmark-Table"),self.textview.open_bookmark_table,"<Alt>B"),
 			(_("Import-Bookmarks"),self.textview.import_bookmarks_from_file,"None"),
 			(_("Bookmark-Table-Complete"),self.textview.open_all_bookmark_table,"<Super>B"),
-			(_("Start/Stop-Reader"),self.start_or_stop_reader,"F5"),
+			(_("Start-Reader"),self.start_reader,"F5"),
+			(_("Stop-Reader"),self.stop_reader,"<Control>F5"),
 			(_("Increase-Reader-Speed"),self.increase_reader_speed,"<Ctrl>Prior"),
 			(_("Decrease-Reader-Speed"),self.decrease_reader_speed,"<Ctrl>Next"),
 			(_("Stop-All-Process"),self.stop_all_process,"<Control>F4")],
@@ -276,7 +279,7 @@ class linux_intelligent_ocr_solution():
 		button_scan = widget.Button(_("Scan"))
 		button_scan.connect_function(self.scan_single_image)		
 		toolbar_main = containers.Toolbar(containers.Toolbar.HORIZONTAL,
-			[(_("_Preferences"),self.open_preferences_general_page),
+			[(_("Preferences"),self.open_preferences_general_page),
 			(_("Video-Tutorials"),self.open_video_tutorials),
 			(_("About"),self.about),
 			(_("Quit"),self.quit)])				
@@ -325,6 +328,12 @@ class linux_intelligent_ocr_solution():
 					self.textview.set_text(file.read())
 				except:
 					pass
+		else:
+			try:
+				file = open(macros.recent_file_path,encoding="utf-8")
+				self.textview.set_text(file.read())
+			except:
+				pass
 		
 		
 		self.old_language = -1
@@ -335,7 +344,8 @@ class linux_intelligent_ocr_solution():
 		self.make_preferences_effective()
 		
 		# Text TTS reading switch
-		self.reading_breaker = True
+		self.is_reading = False
+		self.reader_stop_pressed = False
 
 		self.notify_information(_("Welcome to {} Version {}").format(macros.app_name,macros.version),0)
 
@@ -401,11 +411,14 @@ class linux_intelligent_ocr_solution():
 
 	def list_updated_event_handler(self,*data):
 		filename = self.imageview.get_filename()
-		file = open(filename+".box","w")
-		for item in self.imageview.get_list():
-			file.write("{0} {1} {2} {3} {4} 0\n".format(str(item[0]),
-			str(int(item[1])),str(int(item[2])),
-			str(int(item[3])),str(int(item[4]))))
+		if(filename == macros.logo_file):
+			self.imageview.clear_selection(None)
+		else:
+			file = open(filename+".box","w")
+			for item in self.imageview.get_list():
+				file.write("{0} {1} {2} {3} {4} 0\n".format(str(item[0]),
+				str(int(item[1])),str(int(item[2])),
+				str(int(item[3])),str(int(item[4]))))
 
 	@on_thread
 	def save_selected_areas(self,*data):
@@ -423,6 +436,9 @@ class linux_intelligent_ocr_solution():
 			with open(macros.recent_file_path,"w") as file:
 				file.write("")
 
+	def audio_converter(self,*data):
+		self.textview.audio_converter(voice=self.preferences.speech_language)
+
 	def go_to_page(self,*data):
 		spinbutton_page = widget.SpinButton(0,0,self.preferences.starting_page_number,1,5,0)
 		dlg = dialog.Dialog(_("Go to page"),(_("Go"), dialog.Dialog.BUTTON_ID_1,_("Close!"), dialog.Dialog.BUTTON_ID_2))
@@ -432,6 +448,8 @@ class linux_intelligent_ocr_solution():
 		response = dlg.run()
 		if response == dialog.Dialog.BUTTON_ID_1:
 			to_go = spinbutton_page.get_value()
+			# Start search from begining to match properly
+			self.textview.move_cursor_to_line(1)
 			if (self.preferences.page_numbering_type == 0):
 				word = "Page-{0}".format(to_go)
 			else:
@@ -493,39 +511,10 @@ class linux_intelligent_ocr_solution():
 		shutil.copyfile(pdf_filename_full,destination)
 		os.makedirs(destination.split(".")[0],exist_ok=True)
 
-		out = subprocess.getoutput("pdffonts {}".format(destination))
-		pdf_type = "Text"
-		if (len(out) < 300):
-			pdf_type = "Image"
-
-		dlg_set_tool = dialog.Dialog(_("Select PDF Type"),
-		(_("Containing images only"), dialog.Dialog.BUTTON_ID_2,
-		_("Containing text or images"), dialog.Dialog.BUTTON_ID_1))
-
-
-		label = widget.Label(_(
-		"Please select PDF Type. Seems to me that {} is a {} PDF."
-		.format(pdf_filename, pdf_type)))
-
-		dlg_set_tool.add_widget(label)
-		label.show()
-
-		# Sleep 1 second for avoiding freeze while opening with pdf file
-		time.sleep(1)
-
-		loop.acquire_lock()
-		response = dlg_set_tool.run()
-		if(response == dialog.Dialog.BUTTON_ID_1):
-			conversion_tool = "pdftoppm"
-		else:
-			conversion_tool = "pdfimages"
-		dlg_set_tool.destroy()
-		loop.release_lock()
-
 		self.notify_information(_("Extracting images from Pdf"))
 
-		p = multiprocessing.Process(target=lambda : os.system("{} {} {}/{} -png"
-		.format(conversion_tool, destination,destination.split(".")[0],pdf_filename.split(".")[0])) , args=())
+		p = multiprocessing.Process(target=lambda : os.system("pdftoppm {} {}/{} -png"
+		.format(destination,destination.split(".")[0],pdf_filename.split(".")[0])) , args=())
 		
 		p.start()
 		while(p.is_alive()):
@@ -676,7 +665,7 @@ class linux_intelligent_ocr_solution():
 			loop.release_lock()
 		except Exception as ex:
 			loop.acquire_lock()
-			self.notify_information(ex,0)
+			self.notify_information("Scanner list update error : "+str(ex),0)
 			loop.release_lock()
 		finally:
 			self.is_updating_scanner_list = False
@@ -741,11 +730,9 @@ class linux_intelligent_ocr_solution():
 			
 		if(self.process_breaker):
 			return
-		print(_("Adding image to list"))
 		loop.acquire_lock()
 		self.iconview.add_item(filename)
 		loop.release_lock()
-		print(_("Image added"))
 		if(self.process_breaker):
 			return
 		
@@ -763,7 +750,6 @@ class linux_intelligent_ocr_solution():
 		
 		print(language)
 		rotation_list = [00,90,180,270]
-		print("Angle = ",angle)
 		if mode == 2:	#Manual
 			if(angle not in rotation_list):
 				os.system("convert -rotate {0} {1} {1}".format(rotation_list[angle],file_name))
@@ -849,34 +835,26 @@ class linux_intelligent_ocr_solution():
 		for i in range(0,self.preferences.number_of_pages_to_scan):
 			destination = "{0}{1}.jpg".format(macros.tmp_dir,self.preferences.get_page_number_as_string())
 			destination = self.get_feesible_filename_from_filename(destination)
-			print(_("#Scanning"))
 			t = threading.Thread(target=self.scan,args=(destination,))
 			t.start()
 			while(t.is_alive()):
 				pass
-			print(_("#Scan Compleated"))
 			if(self.process_breaker):
 				break
 			time.sleep(self.preferences.time_between_repeated_scanning)	
 			if(self.process_breaker):
 				break
-			print(_("#Running OCR"))	
 			self.notify_information(_("Recognizing {}").format(destination))
 			text,angle = self.ocr(destination,mode,angle)	
-			print(_("#Placing text and cursor"))
 			if (i == 0):
-				self.insert_text_to_textview(text,True,True)
+				self.insert_text_to_textview(text,True,self.preferences.give_page_number)
 			else:
-				self.insert_text_to_textview(text,False,True)
-			print(_("#Placing text and cursor Finished"))				
-			print(_("#Redraw"))
+				self.insert_text_to_textview(text,False,self.preferences.give_page_number)
 			self.imageview.redraw()
-			print(_("#Redraw Compleated"))
 			loop.acquire_lock()
 			self.iconview.reload_preview(destination)
 			self.notify_information(_("Page {}").format(self.preferences.get_page_number_as_string()),0)
 			loop.release_lock()
-			print(_("#Preview Updated"))
 			self.preferences.update_page_number()
 			
 			if mode == 1: #Change the mode partial automatic to Manual
@@ -885,7 +863,6 @@ class linux_intelligent_ocr_solution():
 							
 			if(self.process_breaker):
 				break
-			print(_("#Compleated "),i);
 		self.notify_information(_("Compleated"),0)
 		#self.announce(_("Job completed!")
 		#self.make_scanner_widgets_active(lock=True)
@@ -929,7 +906,7 @@ class linux_intelligent_ocr_solution():
 		value = self.preferences.scan_brightness;
 		distance = 10; start = 10; end = 90;
 		count = None
-		result_text = "<b>Click 'Optimize' to start optimisation </b>" 
+		result_text = _("<b>Click 'Optimize' to start optimisation </b>")
 		while(1):
 			loop.acquire_lock()
 			dlg = dialog.Dialog(_("Optimize Scanner-Brightness"),
@@ -987,7 +964,7 @@ class linux_intelligent_ocr_solution():
 				(_("Yes set this rotation"), dialog.Dialog.BUTTON_ID_1,
 				_("No continue with existing mode"), dialog.Dialog.BUTTON_ID_2))
 				label = widget.Label(_("Do you want to fix the angle at {}\
-				\ndegree manual rotation ?".format(angle)))
+				\ndegree manual rotation ?").format(angle))
 				dlg_set_mode.add_widget(label)
 				label.show()
 				response = dlg_set_mode.run()
@@ -1022,9 +999,9 @@ class linux_intelligent_ocr_solution():
 				#self.make_preferences_widgets_active(lock=True)
 				return True
 			count, value = list[0][0],list[0][1];
-			result_text = "<b>Optimisation Result "
+			result_text = _("<b>Optimisation Result ")
 			for item in list:
-				result_text += "\nGot {} Words at brightness {}".format(item[0], item[1])
+				result_text += _("\nGot {} Words at brightness {}").format(item[0], item[1])
 			result_text += "</b>" 
 			start = value-distance;
 			end = value+distance;
@@ -1075,7 +1052,7 @@ class linux_intelligent_ocr_solution():
 		#self.scanner_objects[selected_scanner].cancel()
 		os.system("pkill convert")
 		self.available_ocr_engine_list[self.preferences.ocr_engine].cancel()
-		self.notify_information("Terminated",0)
+		self.notify_information(_("Terminated"),0)
 		
 	def open_readme(self,*data):
 		if(self.textview.get_modified()):
@@ -1099,32 +1076,38 @@ class linux_intelligent_ocr_solution():
 		#self.make_ocr_widgets_inactive(lock=True)
 		#self.make_preferences_widgets_inactive(lock=True)
 		#self.make_image_widgets_inactive(lock=True)
-		progress_step = 1/len(self.iconview.get_selected_item_names())
-		progress = 0;
-		mode = self.preferences.mode_of_rotation
-		angle = self.preferences.rotation_angle
-		for item in self.iconview.get_selected_item_names():
-			self.notify_information(_("Running OCR on selected image {}")
-			.format(item))
+		items = self.iconview.get_selected_item_names();
+		length = len(items)
+		if (length > 0):
+			progress_step = 1/len(self.iconview.get_selected_item_names())
+			progress = 0;
+			mode = self.preferences.mode_of_rotation
+			angle = self.preferences.rotation_angle
+			for item in self.iconview.get_selected_item_names():
+				self.notify_information(_("Running OCR on selected image {}")
+				.format(item))
 			
-			#self.announce(_("Recognising {}").format(self.liststore_images[item[0]][1]))
-			progress = progress + progress_step;			
-			text,angle = self.ocr(item,mode,angle)
-			self.insert_text_to_textview(text,self.preferences.insert_position,True)
-			self.preferences.update_page_number()
-			loop.acquire_lock()
-			self.iconview.reload_preview(item)
-			loop.release_lock()
-			if mode == 1:#Changing partial automatic to Manual
-				mode = 2
-				#self.announce(_("Angle to be rotated = {}").format(angle))
-			if(self.process_breaker):
-				break
-		self.imageview.redraw()
-		#self.make_ocr_widgets_active(lock=True)
-		#self.make_preferences_widgets_active(lock=True)
-		#self.make_image_widgets_active(lock=True)
-		self.notify_information(_("completed!"),0)
+				#self.announce(_("Recognising {}").format(self.liststore_images[item[0]][1]))
+				progress = progress + progress_step;
+				text,angle = self.ocr(item,mode,angle)
+				self.insert_text_to_textview(text,self.preferences.insert_position,self.preferences.give_page_number)
+				self.preferences.update_page_number()
+				loop.acquire_lock()
+				self.iconview.reload_preview(item)
+				loop.release_lock()
+				if mode == 1:#Changing partial automatic to Manual
+					mode = 2
+					#self.announce(_("Angle to be rotated = {}").format(angle))
+				if(self.process_breaker):
+					break
+			self.imageview.redraw()
+			#self.make_ocr_widgets_active(lock=True)
+			#self.make_preferences_widgets_active(lock=True)
+			#self.make_image_widgets_active(lock=True)
+			self.notify_information(_("completed!"),0)
+		else:
+			self.notify_information(_("No item selected!"),0)
+
 				
 	def ocr_all_images_with_rotation(self,widget):
 		self.iconview.select_all()
@@ -1136,20 +1119,25 @@ class linux_intelligent_ocr_solution():
 		#self.make_ocr_widgets_inactive(lock=True)
 		#self.make_preferences_widgets_inactive(lock=True)
 		#self.make_image_widgets_inactive(lock=True)
-		progress_step = 1/len(self.iconview.get_selected_item_names())
-		progress = 0;
-		for item in self.iconview.get_selected_item_names():
-			self.notify_information(_("Running OCR on selected image {} (without rotating)")
-			.format(item))
-			
-			#self.announce(_("Recognising {} without rotating").format(self.liststore_images[item[0]][1]))
-			progress = progress + progress_step;
-			text,angle = self.ocr(item,2,00)
-			self.insert_text_to_textview(text,self.preferences.insert_position,True)
-			self.preferences.update_page_number()
-			if(self.process_breaker):
-				break
-		self.notify_information(_("completed!"),0)
+		items = self.iconview.get_selected_item_names();
+		length = len(items)
+		if (length > 0):
+			progress_step = 1/length
+			progress = 0;
+			for item in items:
+				self.notify_information(_("Running OCR on selected image {} (without rotating)")
+				.format(item))
+
+				#self.announce(_("Recognising {} without rotating").format(self.liststore_images[item[0]][1]))
+				progress = progress + progress_step;
+				text,angle = self.ocr(item,2,00)
+				self.insert_text_to_textview(text,self.preferences.insert_position,self.preferences.give_page_number)
+				self.preferences.update_page_number()
+				if(self.process_breaker):
+					break
+			self.notify_information(_("completed!"),0)
+		else:
+			self.notify_information(_("No item selected!"),0)
 		#self.announce(_("Completed!"))
 		#self.make_ocr_widgets_active(lock=True)
 		#self.make_preferences_widgets_active(lock=True)
@@ -1240,7 +1228,7 @@ class linux_intelligent_ocr_solution():
 		elif (len(item_list) == 1):
 			dlg = FileChooserDialog(_("Filename please"),
 				FileChooserDialog.SAVE,macros.supported_image_formats,
-				macros.home_dir);
+				macros.user_home_path);
 			response = dlg.run()
 			if response == FileChooserDialog.ACCEPT:
 				shutil.copy(item_list[0],dlg.get_filename())
@@ -1248,7 +1236,7 @@ class linux_intelligent_ocr_solution():
 		else:
 			dlg = FileChooserDialog(_("Select Folder to save images"),
 				FileChooserDialog.OPEN_FOLDER,macros.supported_image_formats,
-				macros.home_dir);
+				macros.user_home_path);
 			response = dlg.run()
 			if response == FileChooserDialog.ACCEPT:
 				directory = dlg.get_current_folder()
@@ -1263,7 +1251,7 @@ class linux_intelligent_ocr_solution():
 		
 	def save_selected_images_as_pdf(self,widget):
 		dlg = FileChooserDialog(_("Give pdf filename(with extention) to save images"),
-			FileChooserDialog.SAVE,macros.supported_pdf_formats,macros.home_dir)
+			FileChooserDialog.SAVE,macros.supported_pdf_formats,macros.user_home_path)
 		response = dlg.run()
 		if response == FileChooserDialog.ACCEPT:
 			file_name = dlg.get_filename()
@@ -1271,7 +1259,6 @@ class linux_intelligent_ocr_solution():
 			for item in self.iconview.get_selected_item_names():
 				command += item + " "
 			command += '"'+file_name+'"'
-			print("File name : ",file_name)
 			os.system(command)
 		dlg.destroy()
 
@@ -1333,7 +1320,7 @@ class linux_intelligent_ocr_solution():
 				dlg = dialog.Dialog(_("Dictionary not found!"), (_("Ok"),dialog.Dialog.BUTTON_ID_1))
 				label = widget.Label(_(
  """Please install aspell, ispell, hunspell, myspell, or uspell 
-dictionary for your language({0}) and restart Lios!
+dictionary for your language and restart Lios!
 Otherwise spellchecker and auto-rotation will work with english(fallback). 
 
 For example on debian based system one can install aspell or 
@@ -1348,7 +1335,7 @@ On rpm based system use
 yum install aspell-fr
 			
 On arch based system use 
-pacman -S aspell-fr""").format(languages[self.preferences.language]))
+pacman -S aspell-fr"""))
 				dlg.add_widget(label)
 				label.show()
 				dlg.run()
@@ -1369,8 +1356,8 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 		self.textview.set_highlight_background(self.preferences.background_highlight_color)
 				
 	def save_preferences(self,*data):
-		save_preferences_dlg = FileChooserDialog(_("save_preferences as "),
-		FileChooserDialog.SAVE,["cfg"],macros.home_dir)
+		save_preferences_dlg = FileChooserDialog(_("Save preferences as "),
+		FileChooserDialog.SAVE,["cfg"],macros.user_home_path)
 		response = save_preferences_dlg.run()		
 		if response == FileChooserDialog.ACCEPT:
 			self.preferences.save_to_file(save_preferences_dlg.get_filename()+".cfg")
@@ -1381,7 +1368,7 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 
 	def load_preferences(self,*data):
 		load_preferences_dlg = FileChooserDialog(_("Select the image"),
-			FileChooserDialog.OPEN,["cfg"],macros.home_dir)
+			FileChooserDialog.OPEN,["cfg"],macros.user_home_path)
 		response = load_preferences_dlg.run()
 		if response == FileChooserDialog.ACCEPT:
 			self.preferences.set_from_file(load_preferences_dlg.get_filename())
@@ -1414,8 +1401,8 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 		file_chooser_open_files = FileChooserDialog(_("Select files to open"),
 				FileChooserDialog.OPEN,macros.supported_image_formats+
 				  macros.supported_text_formats+macros.supported_pdf_formats,
-				  macros.home_dir)
-		file_chooser_open_files.set_current_folder(macros.home_dir)
+				  macros.user_home_path)
+		file_chooser_open_files.set_current_folder(macros.user_home_path)
 		file_chooser_open_files.set_select_multiple(True)
 		response = file_chooser_open_files.run()
 		if response == FileChooserDialog.ACCEPT:
@@ -1449,11 +1436,9 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 					self.textview.insert_text(text,editor.BasicTextView.AT_END)
 
 	@on_thread
-	def start_or_stop_reader(self,*data):
-		if (self.reading_breaker == False):
-			self.reading_breaker = True
-		else:
-			self.reading_breaker = False
+	def start_reader(self,*data):
+		if(self.is_reading == False and self.reader_stop_pressed == False):
+			self.is_reading = True
 			speaker = speech.Speech()
 			speaker.set_output_module(speaker.list_output_modules()[self.preferences.speech_module])
 			if(self.preferences.speech_module != -1 and len(speaker.list_voices()) > 1):
@@ -1467,9 +1452,19 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 				speaker.say(sentence)
 				loop.release_lock()
 				speaker.wait()
-				if(self.reading_breaker):
-					break
+				if(self.reader_stop_pressed == True):
 					speaker.close()
+					self.is_reading = False;
+					self.reader_stop_pressed = False
+					break
+
+			self.is_reading = False;
+			self.reader_stop_pressed = False
+
+
+	def stop_reader(self, *data):
+		if(self.is_reading):
+			self.reader_stop_pressed = True
 	
 	def increase_reader_speed(self,*data):
 		if (self.preferences.speech_rate < 100):
@@ -1489,9 +1484,9 @@ pacman -S aspell-fr""").format(languages[self.preferences.language]))
 		self.add_image_to_list(filename,"/tmp/Lios/{}".format(filename.split("/")[2]),True,False)
 	
 	def about(self,*data):
-		dlg = about.AboutDialog("Lios",None)
-		dlg.set_name("Linux-Intelligent-Ocr-Solution")
-		dlg.set_program_name("Linux-Intelligent-Ocr-Solution")
+		dlg = about.AboutDialog(_("Lios"),None)
+		dlg.set_name(_("Linux-Intelligent-Ocr-Solution"))
+		dlg.set_program_name(_("Linux-Intelligent-Ocr-Solution"))
 		dlg.set_version(macros.version)
 		dlg.set_logo_from_file(macros.logo_file)
 		dlg.set_comments(_("Lios is a free and open source software\n \
